View source: R/setup_bolt4jr.R
| setup_bolt4jr | R Documentation |
This function initializes the Conda environment required for the bolt4jr package.
If no Conda binary is found, it installs Miniconda. If the required Conda environment
(bolt4jr) is not found, it creates the environment and installs the necessary dependencies.
setup_bolt4jr()
The function ensures that:
A Conda binary is available.
A Conda environment named bolt4jr exists.
The neo4j Python package is installed in the bolt4jr environment.
Call this function manually before using any functionality that relies on Python.
No return value, called for side effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.